fino
====

[![Build Status](https://travis-ci.org/hugovk/fino.svg?branch=master)](https://travis-ci.org/hugovk/fino)
[![Coverage Status](https://coveralls.io/repos/github/hugovk/fino/badge.svg?branch=master)](https://coveralls.io/github/hugovk/fino?branch=master)
[![Code Health](https://landscape.io/github/hugovk/fino/master/landscape.svg)](https://landscape.io/github/hugovk/fino/master)

Output the Finnish word for a given integer.

 * Used by [hugovk/everyfinnishno](https://github.com/hugovk/everyfinnishno) to tweet [@EveryFinnishNo](https://twitter.com/EveryFinnishNo).
